# Footprint based analysis and causal network contextualisation in SARS-CoV-2 infected A549 cell line

## Introduction

This repository contains the code to reproduce the analysis presented in section mentioned in the project title contained in the article: *A versatile and interoperable computational framework for the analysis and modelling of COVID-19 disease mechanisms*. 

## Procedure Details 

We obtained the transcriptomics dataset from the GEO database with accession number [GSE147507](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE147507) ([Blanco-Melo et al., 2020](https://doi.org/10.1016/j.cell.2020.04.026)). We extracted the series number 5 from the dataset, consisting of 2 conditions in triplicate, A549 cells treated with a mock and A549 infected with SARS-CoV-2, measured 24 hours after infection. Differential analysis of the transcript abundances was performed using DESeq2 ([Love et al., 2014](https://doi.org/10.1186/s13059-014-0550-8)). The resulting t-values of the differential analysis were used as input to estimate pathway activity deregulation using Progeny ([Schubert et al., 2018](https://doi.org/10.1038/s41467-017-02391-6)). The differential analysis t-values were also used to estimate the deregulation of TF activities using Dorothea ([Garcia-Alonso et al., 2019](http://www.genome.org/cgi/doi/10.1101/gr.240663.118)) as a source of TF-target regulon and the Viper algorithm ([Alvarez et al., 2016](https://doi.org/10.1038/ng.3593)) to estimate the TF activity score. 

Phosphoproteomic data of mock-treated and SARS-CoV.2 infected cells were extracted from ([Stukalov et al., 2021](https://doi.org/10.1038/s41586-021-03493-4)). Phosphosite differential analysis log2FC was used to estimate the deregulation of kinase activities using ([Bachman et al., 2019](https://doi.org/10.1101/822668)) as a source of kinase-substrate interactions and a z-test to estimate kinase activity score ([Bouhaddou et al., 2020](https://doi.org/10.1016/j.cell.2020.06.034), [Hernandez-Armenta et al., 2017](https://doi.org/10.1093/bioinformatics/btx082))

Finally, we used Carnival ([Liu et al., 2019](https://doi.org/10.1038/s41540-019-0118-z)) with the COSMOS approach ([Dugourd et al., 2021](https://doi.org/10.15252/msb.20209730)) to connect the top 10 deregulated kinases with the top 30 deregulated TFs with a Prior Knowledge Network assembled from OmniPath resources  ([Türei et al., 2021](https://doi.org/10.1101/2020.08.03.221242)). Progeny pathway activity scores were used to weigh the PKN and facilitate the optimal network search to connect kinases and TFs.

To place our results in the context of the whole study, we matched the genes obtained in carnival results with those included in the curated pathways by the [Covid-19 Disease map community](https://covid.pages.uni.lu/map_contents). In addition, we matched our results with an harmonised list containing drug-targets. 

## Markdowns

1. The notebook containing the footprint-based analysis can be found [here](https://git-r3lab.uni.lu/computational-modelling-and-simulation/footprint-based-analysis-and-causal-network-contextualisation-in-sars-cov-2-infected-a549-cell-line/-/blob/master/02_Carnival_Transcriptomics_phosphoprotemicsMann.md).
2. The notebook containing the analysis to match the footprint-based results with the content of the disease map communicaty can be found [here](https://git-r3lab.uni.lu/computational-modelling-and-simulation/footprint-based-analysis-and-causal-network-contextualisation-in-sars-cov-2-infected-a549-cell-line/-/blob/master/Matching_with_Covid19DM_Diagrams/grep_disease_maps.md). The results are stored [here](https://gitlab.lcsb.uni.lu/computational-modelling-and-simulation/footprint-based-analysis-and-causal-network-contextualisation-in-sars-cov-2-infected-a549-cell-line/-/blob/master/Matching_with_Covid19DM_Diagrams/MatchingGenes/carnival_diagrams.tsv)
3. The notebook containing the analysis to match the footprint-based results with drug-targets can be found [here](https://gitlab.lcsb.uni.lu/computational-modelling-and-simulation/footprint-based-analysis-and-causal-network-contextualisation-in-sars-cov-2-infected-a549-cell-line/-/blob/master/Matching_with_DrugTargets/grep_drug_targets.md). The results are stored [here](https://gitlab.lcsb.uni.lu/computational-modelling-and-simulation/footprint-based-analysis-and-causal-network-contextualisation-in-sars-cov-2-infected-a549-cell-line/-/blob/master/Matching_with_DrugTargets/MatchingDrugs/carnival_drugs.tsv) 
